@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 import aws_cdk.aws_applicationautoscaling._jsii
 import aws_cdk.aws_autoscaling._jsii
@@ -19,10 +19,13 @@ import aws_cdk.aws_ecr_assets._jsii
 import aws_cdk.aws_elasticloadbalancing._jsii
 import aws_cdk.aws_elasticloadbalancingv2._jsii
 import aws_cdk.aws_iam._jsii
+import aws_cdk.aws_kms._jsii
 import aws_cdk.aws_lambda._jsii
 import aws_cdk.aws_logs._jsii
 import aws_cdk.aws_route53._jsii
 import aws_cdk.aws_route53_targets._jsii
+import aws_cdk.aws_s3._jsii
+import aws_cdk.aws_s3_assets._jsii
 import aws_cdk.aws_secretsmanager._jsii
 import aws_cdk.aws_servicediscovery._jsii
 import aws_cdk.aws_sns._jsii
@@ -33,7 +36,7 @@ import aws_cdk.cx_api._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "@aws-cdk/aws-ecs", "1.57.0", __name__[0:-6], "aws-ecs@1.57.0.jsii.tgz"
+    "@aws-cdk/aws-ecs", "1.106.0", __name__[0:-6], "aws-ecs@1.106.0.jsii.tgz"
 )
 
 __all__ = [
